@@ -21,7 +21,7 @@ class SO3:
         derivative: bool, whether to calculate the gradient of not
     '''
 
-    def __init__(self, nmax, lmax, rcut, alpha=2.0, derivative=True, stress=False):
+    def __init__(self, nmax=3, lmax=3, rcut=3.5, alpha=2.0, derivative=True, stress=False):
         # populate attributes
         self.nmax = nmax
         self.lmax = lmax
@@ -29,10 +29,39 @@ class SO3:
         self.alpha = alpha
         self.derivative = derivative
         self.stress = stress
+        self._type = "SO3"
         return
 
+    def __str__(self):
+        s = "SO3 descriptor with Cutoff: {:6.3f}".format(self.rcut)
+        s += " lmax: {:d}, nmax: {:d}, alpha: {:.3f}\n".format(self.lmax, self.nmax, self.alpha)
+        return s
+
     def __repr__(self):
-        return """SO3 smooth power spectrum calculator"""
+        return str(self)
+
+    def load_from_dict(self, dict0):
+        self.nmax = dict0["nmax"]
+        self.lmax = dict0["lmax"]
+        self.rcut = dict0["rcut"]
+        self.alpha = dict0["alpha"]
+        self.derivative = dict0["derivative"]
+        self.stress = dict0["stress"]
+
+    def save_dict(self):
+        """
+        save the model as a dictionary in json
+        """
+        dict = {"nmax": self.nmax,
+                "lmax": self.lmax,
+                "rcut": self.rcut,
+                "alpha": self.alpha,
+                "derivative": self.derivative,
+                "stress": self.stress,
+                "_type": "SO3", 
+               }
+        return dict
+
 
     @property
     def nmax(self):
@@ -255,8 +284,9 @@ class SO3:
 
 
         for i in range(len(Neighbors)):
-            neighborlist[i, :len(Neighbors[i]), :] = Neighbors[i]
-            atm_nums[i, :len(Neighbors[i])] = Atomic_numbers[i]
+            if len(Neighbors[i]) > 0:
+                neighborlist[i, :len(Neighbors[i]), :] = Neighbors[i]
+                atm_nums[i, :len(Neighbors[i])] = Atomic_numbers[i]
 
 
 
